Pecos
=======================================

[![TravisCI](https://travis-ci.org/sandialabs/pecos.svg?branch=master)](https://travis-ci.org/sandialabs/pecos)
[![Coverage Status](https://coveralls.io/repos/github/sandialabs/pecos/badge.svg?branch=master)](https://coveralls.io/github/sandialabs/pecos?branch=master)
[![Documentation Status](https://readthedocs.org/projects/pecos/badge/?version=latest)](http://pecos.readthedocs.org/en/latest/)

Advances in sensor technology have rapidly increased our ability to monitor 
natural and human-made physical systems.  
In many cases, it is critical to process the resulting large volumes of data on a regular schedule
and alert system operators when the system has changed.
Automated quality control and performance monitoring can allow system 
operators to quickly detect performance issues.  

Pecos is an open source python package designed to address this need.
Pecos includes built-in functionality to monitor performance of time series data, 
subject to a series of quality control tests.
The python package includes methods to run quality control tests defined by the user
and generate reports which include performance metrics, test results, and graphics.
The software was developed specifically for solar photovoltaic system 
monitoring, but it can be customized for other applications.

For more information, go to http://pecos.readthedocs.io

License
------------

Revised BSD.  See the LICENSE.txt file.

Organization
------------

Directories
  * pecos - python package
  * documentation - user manual
  * examples - examples

Contact
-------
   * Katherine Klise, Sandia National Laboratories, kaklise@sandia.gov
   * Joshua Stein, Sandia National Laboratories, jsstein@sandia.gov
